==> aroundme_0_7_0.zip: aroundme_0_7_0/aroundme/components/core/language/1/barnraiser_01/msg_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once($language_path . 'inc/me_common.inc.php');


$lang['message']['reply']['insert'] = 				"> ";
$lang['message']['reply']['greeting'] = 			"Hi";
$lang['message']['reply']['greeting_end'] = 		",";
$lang['message']['reply']['re'] = 					"RE";


// HEADER
$lang['hdr_message'] = 							"message";
$lang['hdr_recipient'] = 						"recipient";


//SUBMIT BUTTONS
$lang['sub_preview'] = 							"preview";
$lang['sub_send'] = 							"send";


// ERROR MESSAGE
$lang['error']['no_receiver_error'] = 			"You need to check at least one checkbox to send a message.";


// TEXTS
$lang['txt_to'] = 								"to";
$lang['txt_subject'] = 							"subject";
$lang['txt_body'] = 							"message";
$lang['txt_tags'] = 							"tags";
$lang['txt_mark_all'] = 						"mark all";
$lang['txt_priority'] = 						"priority";
$lang['txt_response'] = 						"response";


// EMAIL
$lang['subject_email_message'] = 				"AROUNDMe message notification";

?>

==> aroundme_0_7_6.zip: aroundme_0_7_6/aroundme/components/core/language/1/barnraiser_01/msg_edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

include_once($language_path . 'inc/me_common.inc.php');


$lang['message']['reply']['insert'] = 				"> ";
$lang['message']['reply']['greeting'] = 			"Hi";
$lang['message']['reply']['greeting_end'] = 		",";
$lang['message']['reply']['re'] = 					"RE";


// HEADER
$lang['hdr_message'] = 							"message";
$lang['hdr_recipient'] = 						"recipient";
$lang['hdr_no_pref'] = 							"message send preferences not set";


//SUBMIT BUTTONS
$lang['sub_preview'] = 							"validate";
$lang['sub_send'] = 							"send";


// ERROR MESSAGE
$lang['error']['no_receiver_error'] = 			"You need to check at least one checkbox to send a message.";


// TEXTS
$lang['txt_to'] = 								"to";
$lang['txt_subject'] = 							"subject";
$lang['txt_body'] = 							"message";
$lang['txt_tags'] = 							"tags";
$lang['txt_mark_all'] = 						"mark all";
$lang['txt_priority'] = 						"priority";
$lang['txt_response'] = 						"response";
$lang['hdr_no_pref_intro'] = 					"You cannot compose a message. This is either because the person you are trying to message has not set their identity to allow messages at this time or because you have no one in your immediate network.";
$lang['txt_copy_to_out'] = 						"Add a copy of this message to my out box?";

// EMAIL
$lang['subject_email_message'] = 				"AROUNDMe message notification";

?>
